OwnedSocket

Struct OwnedSocket 

1.63.0 · Source
pub struct OwnedSocket { /* private fields */ }
Available on Windows only.
An owned socket.

This closes the socket on drop.

This uses repr(transparent) and has the representation of a host socket, so it can be used in FFI in places where a socket is passed as a consumed argument or returned as an owned value, and it never has the value INVALID_SOCKET.

Implementations

Source

impl OwnedSocket

1.63.0 · Source

pub fn try_clone(&self) -> Result<Self>

Creates a new OwnedSocket instance that shares the same underlying object as the existing OwnedSocket instance.