pub trait AsRawSocket {
// Required method
fn as_raw_socket(&self) -> RawSocket;
}Available on Windows only.
Extracts raw sockets.
Required Methods
1.0.0 · Sourcefn as_raw_socket(&self) -> RawSocket
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
fn as_raw_socket(&self) -> RawSocket
Extracts the raw socket.
This function is typically used to borrow an owned socket. When used in this way, this method does not pass ownership of the raw socket to the caller, and the socket is only guaranteed to be valid while the original object has not yet been destroyed.
However, borrowing is not strictly required. See AsSocket::as_socket
for an API which strictly borrows a socket.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".